summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--source3/rpc_server/dfs/srv_dfs_nt.c10
-rw-r--r--source3/rpc_server/dssetup/srv_dssetup_nt.c2
-rw-r--r--source3/rpc_server/netlogon/srv_netlog_nt.c2
-rw-r--r--source3/rpc_server/spoolss/srv_spoolss_nt.c93
-rw-r--r--source3/rpc_server/srvsvc/srv_srvsvc_nt.c2
-rw-r--r--source3/rpc_server/svcctl/srv_svcctl_nt.c18
-rw-r--r--source3/rpc_server/winreg/srv_winreg_nt.c14
-rw-r--r--source3/rpc_server/wkssvc/srv_wkssvc_nt.c6
8 files changed, 73 insertions, 74 deletions
diff --git a/source3/rpc_server/dfs/srv_dfs_nt.c b/source3/rpc_server/dfs/srv_dfs_nt.c
index 579651e7597..c04913f53a7 100644
--- a/source3/rpc_server/dfs/srv_dfs_nt.c
+++ b/source3/rpc_server/dfs/srv_dfs_nt.c
@@ -139,7 +139,7 @@ WERROR _dfs_Remove(struct pipes_struct *p, struct dfs_Remove *r)
return WERR_NOT_ENOUGH_MEMORY;
}
if (!strlower_m(altpath)) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
DEBUG(5,("init_reply_dfs_remove: Request to remove %s -> %s\\%s.\n",
r->in.dfs_entry_path, r->in.servername, r->in.sharename));
@@ -329,7 +329,7 @@ WERROR _dfs_Enum(struct pipes_struct *p, struct dfs_Enum *r)
r->out.info->e.info3->count = num_jn;
break;
default:
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
for (i = 0; i < num_jn; i++) {
@@ -344,7 +344,7 @@ WERROR _dfs_Enum(struct pipes_struct *p, struct dfs_Enum *r)
init_reply_dfs_info_3(ctx, &jn[i], &r->out.info->e.info3->s[i]);
break;
default:
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
}
@@ -412,11 +412,11 @@ WERROR _dfs_GetInfo(struct pipes_struct *p, struct dfs_GetInfo *r)
break;
default:
r->out.info->info1 = NULL;
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
if (!ret)
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
return WERR_OK;
}
diff --git a/source3/rpc_server/dssetup/srv_dssetup_nt.c b/source3/rpc_server/dssetup/srv_dssetup_nt.c
index 00065d37a9b..708d2bab524 100644
--- a/source3/rpc_server/dssetup/srv_dssetup_nt.c
+++ b/source3/rpc_server/dssetup/srv_dssetup_nt.c
@@ -79,7 +79,7 @@ static WERROR fill_dsrole_dominfo_basic(TALLOC_CTX *ctx,
return WERR_NOT_ENOUGH_MEMORY;
}
if (!strlower_m(dnsdomain)) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
basic->dns_domain = dnsdomain;
diff --git a/source3/rpc_server/netlogon/srv_netlog_nt.c b/source3/rpc_server/netlogon/srv_netlog_nt.c
index fcb6c8fa5db..2c4277a5fe9 100644
--- a/source3/rpc_server/netlogon/srv_netlog_nt.c
+++ b/source3/rpc_server/netlogon/srv_netlog_nt.c
@@ -211,7 +211,7 @@ WERROR _netr_LogonControl2Ex(struct pipes_struct *p,
fn = "_netr_LogonControl2Ex";
break;
default:
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
switch (r->in.level) {
diff --git a/source3/rpc_server/srvsvc/srv_srvsvc_nt.c b/source3/rpc_server/srvsvc/srv_srvsvc_nt.c
index f62e39d4be9..83c3267c79d 100644
--- a/source3/rpc_server/srvsvc/srv_srvsvc_nt.c
+++ b/source3/rpc_server/srvsvc/srv_srvsvc_nt.c
@@ -1278,7 +1278,7 @@ WERROR _srvsvc_NetFileEnum(struct pipes_struct *p,
ctx = talloc_tos();
ctr3 = r->in.info_ctr->ctr.ctr3;
if (!ctr3) {
- werr = WERR_INVALID_PARAM;
+ werr = WERR_INVALID_PARAMETER;
goto done;
}
diff --git a/source3/rpc_server/svcctl/srv_svcctl_nt.c b/source3/rpc_server/svcctl/srv_svcctl_nt.c
index 2d50ca24ea9..4496b27c538 100644
--- a/source3/rpc_server/svcctl/srv_svcctl_nt.c
+++ b/source3/rpc_server/svcctl/srv_svcctl_nt.c
@@ -494,7 +494,7 @@ WERROR _svcctl_EnumServicesStatusW(struct pipes_struct *p,
ndr = ndr_push_init_ctx(p->mem_ctx);
if (ndr == NULL) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
ndr_err = ndr_push_ENUM_SERVICE_STATUSW_array(
@@ -564,7 +564,7 @@ WERROR _svcctl_ControlService(struct pipes_struct *p,
return info->ops->service_status( info->name,
r->out.service_status );
default:
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
}
@@ -591,7 +591,7 @@ WERROR _svcctl_EnumDependentServicesW(struct pipes_struct *p,
case SERVICE_STATE_ALL:
break;
default:
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
/* we have to set the outgoing buffer size to the same as the
@@ -643,7 +643,7 @@ WERROR _svcctl_QueryServiceStatusEx(struct pipes_struct *p,
ndr_err = ndr_push_struct_blob(&blob, p->mem_ctx, &svc_stat_proc,
(ndr_push_flags_fn_t)ndr_push_SERVICE_STATUS_PROCESS);
if (!NDR_ERR_CODE_IS_SUCCESS(ndr_err)) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
r->out.buffer = blob.data;
@@ -808,7 +808,7 @@ WERROR _svcctl_QueryServiceConfig2W(struct pipes_struct *p,
ndr_err = ndr_push_struct_blob(&blob, p->mem_ctx, &desc_buf,
(ndr_push_flags_fn_t)ndr_push_SERVICE_DESCRIPTION);
if (!NDR_ERR_CODE_IS_SUCCESS(ndr_err)) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
break;
@@ -826,7 +826,7 @@ WERROR _svcctl_QueryServiceConfig2W(struct pipes_struct *p,
ndr_err = ndr_push_struct_blob(&blob, p->mem_ctx, &actions,
(ndr_push_flags_fn_t)ndr_push_SERVICE_FAILURE_ACTIONS);
if (!NDR_ERR_CODE_IS_SUCCESS(ndr_err)) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
break;
@@ -914,7 +914,7 @@ WERROR _svcctl_QueryServiceObjectSecurity(struct pipes_struct *p,
/* TODO: handle something besides SECINFO_DACL */
if ( (r->in.security_flags & SECINFO_DACL) != SECINFO_DACL )
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
/* Lookup the security descriptor and marshall it up for a reply */
sec_desc = svcctl_get_secdesc(p->mem_ctx,
@@ -975,9 +975,9 @@ WERROR _svcctl_SetServiceObjectSecurity(struct pipes_struct *p,
break;
case SECINFO_SACL:
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
default:
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
if ( !(info->access_granted & required_access) )
diff --git a/source3/rpc_server/winreg/srv_winreg_nt.c b/source3/rpc_server/winreg/srv_winreg_nt.c
index cea5598d613..a8d0eb0ec79 100644
--- a/source3/rpc_server/winreg/srv_winreg_nt.c
+++ b/source3/rpc_server/winreg/srv_winreg_nt.c
@@ -253,11 +253,11 @@ WERROR _winreg_QueryValue(struct pipes_struct *p,
return WERR_INVALID_HANDLE;
if (r->in.value_name->name == NULL) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
if ((r->out.data_length == NULL) || (r->out.type == NULL) || (r->out.data_size == NULL)) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
DEBUG(7,("_winreg_QueryValue: policy key name = [%s]\n", regkey->key->name));
@@ -417,7 +417,7 @@ WERROR _winreg_EnumKey(struct pipes_struct *p,
return WERR_INVALID_HANDLE;
if ( !r->in.name || !r->in.keyclass )
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
DEBUG(8,("_winreg_EnumKey: enumerating key [%s]\n", key->key->name));
@@ -447,7 +447,7 @@ WERROR _winreg_EnumValue(struct pipes_struct *p,
return WERR_INVALID_HANDLE;
if ( !r->in.name )
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
DEBUG(8,("_winreg_EnumValue: enumerating values for key [%s]\n",
key->key->name));
@@ -467,7 +467,7 @@ WERROR _winreg_EnumValue(struct pipes_struct *p,
if (r->out.value != NULL) {
if ((r->out.size == NULL) || (r->out.length == NULL)) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
if (val->data.length > *r->out.size) {
@@ -694,7 +694,7 @@ WERROR _winreg_RestoreKey(struct pipes_struct *p,
return WERR_INVALID_HANDLE;
if ( !r->in.filename || !r->in.filename->name )
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
fname = talloc_strdup(p->mem_ctx, r->in.filename->name);
if (!fname) {
@@ -734,7 +734,7 @@ WERROR _winreg_SaveKey(struct pipes_struct *p,
return WERR_INVALID_HANDLE;
if ( !r->in.filename || !r->in.filename->name )
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
fname = talloc_strdup(p->mem_ctx, r->in.filename->name);
if (!fname) {
diff --git a/source3/rpc_server/wkssvc/srv_wkssvc_nt.c b/source3/rpc_server/wkssvc/srv_wkssvc_nt.c
index d47d153c31d..e8520ca57b6 100644
--- a/source3/rpc_server/wkssvc/srv_wkssvc_nt.c
+++ b/source3/rpc_server/wkssvc/srv_wkssvc_nt.c
@@ -828,11 +828,11 @@ WERROR _wkssvc_NetrJoinDomain2(struct pipes_struct *p,
bool ok;
if (!r->in.domain_name) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
if (!r->in.admin_account || !r->in.encrypted_password) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
if (!security_token_has_privilege(token, SEC_PRIV_MACHINE_ACCOUNT) &&
@@ -920,7 +920,7 @@ WERROR _wkssvc_NetrUnjoinDomain2(struct pipes_struct *p,
bool ok;
if (!r->in.account || !r->in.encrypted_password) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
if (!security_token_has_privilege(token, SEC_PRIV_MACHINE_ACCOUNT) &&
diff --git a/source3/rpc_server/spoolss/srv_spoolss_nt.c b/source3/rpc_server/spoolss/srv_spoolss_nt.c
index 18ae6eb8cfd..5d0fa5a0297 100644
--- a/source3/rpc_server/spoolss/srv_spoolss_nt.c
+++ b/source3/rpc_server/spoolss/srv_spoolss_nt.c
@@ -1639,7 +1639,7 @@ WERROR _spoolss_OpenPrinter(struct pipes_struct *p,
werr = _spoolss_OpenPrinterEx(p, &e);
- if (W_ERROR_EQUAL(werr, WERR_INVALID_PARAM)) {
+ if (W_ERROR_EQUAL(werr, WERR_INVALID_PARAMETER)) {
/* OpenPrinterEx returns this for a bad
* printer name. We must return WERR_INVALID_PRINTER_NAME
* instead.
@@ -1700,20 +1700,20 @@ WERROR _spoolss_OpenPrinterEx(struct pipes_struct *p,
int rc;
if (!r->in.printername) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
if (!*r->in.printername) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
if (r->in.userlevel_ctr.level > 3) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
if ((r->in.userlevel_ctr.level == 1 && !r->in.userlevel_ctr.user_info.level1) ||
(r->in.userlevel_ctr.level == 2 && !r->in.userlevel_ctr.user_info.level2) ||
(r->in.userlevel_ctr.level == 3 && !r->in.userlevel_ctr.user_info.level3)) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
/*
@@ -1745,7 +1745,7 @@ WERROR _spoolss_OpenPrinterEx(struct pipes_struct *p,
"handle we created for printer %s\n", r->in.printername));
close_printer_handle(p, r->out.handle);
ZERO_STRUCTP(r->out.handle);
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
/*
@@ -2417,7 +2417,7 @@ static WERROR getprinterdata_printer_server(TALLOC_CTX *mem_ctx,
*type = REG_NONE;
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
/****************************************************************
@@ -4227,7 +4227,7 @@ static WERROR construct_printer_info7(TALLOC_CTX *mem_ctx,
printer = lp_servicename(tmp_ctx, snum);
if (printer == NULL) {
DEBUG(0, ("invalid printer snum %d\n", snum));
- werr = WERR_INVALID_PARAM;
+ werr = WERR_INVALID_PARAMETER;
goto out_tmp_free;
}
@@ -4708,7 +4708,7 @@ WERROR _spoolss_EnumPrinters(struct pipes_struct *p,
/* that's an [in out] buffer */
if (!r->in.buffer && (r->in.offered != 0)) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
DEBUG(4,("_spoolss_EnumPrinters\n"));
@@ -4798,7 +4798,7 @@ WERROR _spoolss_GetPrinter(struct pipes_struct *p,
/* that's an [in out] buffer */
if (!r->in.buffer && (r->in.offered != 0)) {
- result = WERR_INVALID_PARAM;
+ result = WERR_INVALID_PARAMETER;
goto err_info_free;
}
@@ -5738,7 +5738,7 @@ WERROR _spoolss_GetPrinterDriver2(struct pipes_struct *p,
/* that's an [in out] buffer */
if (!r->in.buffer && (r->in.offered != 0)) {
- result = WERR_INVALID_PARAM;
+ result = WERR_INVALID_PARAMETER;
goto err_info_free;
}
@@ -6106,7 +6106,7 @@ static WERROR update_printer_sec(struct policy_handle *handle,
if (secdesc_ctr == NULL) {
DEBUG(10,("update_printer_sec: secdesc_ctr is NULL !\n"));
- result = WERR_INVALID_PARAM;
+ result = WERR_INVALID_PARAMETER;
goto done;
}
@@ -6897,7 +6897,7 @@ static WERROR update_printer(struct pipes_struct *p,
/* Do sanity check on the requested changes for Samba */
if (!check_printer_ok(tmp_ctx, printer, snum)) {
- result = WERR_INVALID_PARAM;
+ result = WERR_INVALID_PARAMETER;
goto done;
}
@@ -7224,7 +7224,7 @@ WERROR _spoolss_AddJob(struct pipes_struct *p,
struct spoolss_AddJob *r)
{
if (!r->in.buffer && (r->in.offered != 0)) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
/* this is what a NT server returns for AddJob. AddJob must fail on
@@ -7234,7 +7234,7 @@ WERROR _spoolss_AddJob(struct pipes_struct *p,
return WERR_UNKNOWN_LEVEL;
}
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
/****************************************************************************
@@ -7361,7 +7361,7 @@ static WERROR enumjobs_level1(TALLOC_CTX *mem_ctx,
pdb = get_print_db_byname(pinfo2->sharename);
if (pdb == NULL) {
- result = WERR_INVALID_PARAM;
+ result = WERR_INVALID_PARAMETER;
goto err_info_free;
}
@@ -7427,7 +7427,7 @@ static WERROR enumjobs_level2(TALLOC_CTX *mem_ctx,
pdb = get_print_db_byname(pinfo2->sharename);
if (pdb == NULL) {
- result = WERR_INVALID_PARAM;
+ result = WERR_INVALID_PARAMETER;
goto err_info_free;
}
@@ -7502,7 +7502,7 @@ static WERROR enumjobs_level3(TALLOC_CTX *mem_ctx,
pdb = get_print_db_byname(pinfo2->sharename);
if (pdb == NULL) {
- result = WERR_INVALID_PARAM;
+ result = WERR_INVALID_PARAMETER;
goto err_info_free;
}
@@ -7555,7 +7555,7 @@ WERROR _spoolss_EnumJobs(struct pipes_struct *p,
/* that's an [in out] buffer */
if (!r->in.buffer && (r->in.offered != 0)) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
if ((r->in.level != 1) && (r->in.level != 2) && (r->in.level != 3)) {
@@ -7930,7 +7930,7 @@ WERROR _spoolss_EnumPrinterDrivers(struct pipes_struct *p,
/* that's an [in out] buffer */
if (!r->in.buffer && (r->in.offered != 0)) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
DEBUG(4,("_spoolss_EnumPrinterDrivers\n"));
@@ -7983,7 +7983,7 @@ WERROR _spoolss_EnumForms(struct pipes_struct *p,
/* that's an [in out] buffer */
if (!r->in.buffer && (r->in.offered != 0) ) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
DEBUG(4,("_spoolss_EnumForms\n"));
@@ -8034,7 +8034,7 @@ WERROR _spoolss_GetForm(struct pipes_struct *p,
if (!r->in.buffer && (r->in.offered != 0)) {
TALLOC_FREE(r->out.info);
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
DEBUG(4,("_spoolss_GetForm\n"));
@@ -8280,7 +8280,7 @@ WERROR _spoolss_EnumPorts(struct pipes_struct *p,
/* that's an [in out] buffer */
if (!r->in.buffer && (r->in.offered != 0)) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
DEBUG(4,("_spoolss_EnumPorts\n"));
@@ -8412,7 +8412,7 @@ static WERROR spoolss_addprinterex_level_2(struct pipes_struct *p,
*/
if (!check_printer_ok(p->mem_ctx, info2, snum)) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
if (devmode == NULL) {
@@ -8509,14 +8509,13 @@ WERROR _spoolss_AddPrinterDriverEx(struct pipes_struct *p,
WERROR err = WERR_OK;
const char *driver_name = NULL;
uint32_t version;
-
/*
* we only support the semantics of AddPrinterDriver()
* i.e. only copy files that are newer than existing ones
*/
if (r->in.flags == 0) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
if (r->in.flags != APD_COPY_NEW_FILES) {
@@ -8637,7 +8636,7 @@ static WERROR compose_spoolss_server_path(TALLOC_CTX *mem_ctx,
pservername = canon_servername(servername);
if (!is_myname_or_ipaddr(pservername)) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
}
@@ -8662,7 +8661,7 @@ static WERROR compose_spoolss_server_path(TALLOC_CTX *mem_ctx,
}
break;
default:
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
if (!*path) {
@@ -8712,7 +8711,7 @@ WERROR _spoolss_GetPrinterDriverDirectory(struct pipes_struct *p,
if (!r->in.buffer && (r->in.offered != 0)) {
TALLOC_FREE(r->out.info);
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
DEBUG(5,("_spoolss_GetPrinterDriverDirectory: level %d\n",
@@ -8983,7 +8982,7 @@ WERROR _spoolss_AddForm(struct pipes_struct *p,
form = r->in.info_ctr->info.info1;
if (!form) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
switch (form->flags) {
@@ -8992,7 +8991,7 @@ WERROR _spoolss_AddForm(struct pipes_struct *p,
case SPOOLSS_FORM_PRINTER:
break;
default:
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
tmp_ctx = talloc_new(p->mem_ctx);
@@ -9136,7 +9135,7 @@ WERROR _spoolss_SetForm(struct pipes_struct *p,
form = r->in.info_ctr->info.info1;
if (!form) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
tmp_ctx = talloc_new(p->mem_ctx);
@@ -9236,7 +9235,7 @@ WERROR _spoolss_EnumPrintProcessors(struct pipes_struct *p,
/* that's an [in out] buffer */
if (!r->in.buffer && (r->in.offered != 0)) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
DEBUG(5,("_spoolss_EnumPrintProcessors\n"));
@@ -9338,7 +9337,7 @@ WERROR _spoolss_EnumPrintProcessorDataTypes(struct pipes_struct *p,
/* that's an [in out] buffer */
if (!r->in.buffer && (r->in.offered != 0)) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
DEBUG(5,("_spoolss_EnumPrintProcessorDataTypes\n"));
@@ -9505,7 +9504,7 @@ WERROR _spoolss_EnumMonitors(struct pipes_struct *p,
/* that's an [in out] buffer */
if (!r->in.buffer && (r->in.offered != 0)) {
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
DEBUG(5,("_spoolss_EnumMonitors\n"));
@@ -9571,7 +9570,7 @@ static WERROR getjob_level_1(TALLOC_CTX *mem_ctx,
if (found == false) {
/* NT treats not found as bad param... yet another bad choice */
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
return fill_job_info1(mem_ctx,
@@ -9609,7 +9608,7 @@ static WERROR getjob_level_2(TALLOC_CTX *mem_ctx,
if (found == false) {
/* NT treats not found as bad param... yet another bad
choice */
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
/*
@@ -9659,7 +9658,7 @@ WERROR _spoolss_GetJob(struct pipes_struct *p,
/* that's an [in out] buffer */
if (!r->in.buffer && (r->in.offered != 0)) {
- result = WERR_INVALID_PARAM;
+ result = WERR_INVALID_PARAMETER;
goto err_jinfo_free;
}
@@ -9674,7 +9673,7 @@ WERROR _spoolss_GetJob(struct pipes_struct *p,
svc_name = lp_const_servicename(snum);
if (svc_name == NULL) {
- result = WERR_INVALID_PARAM;
+ result = WERR_INVALID_PARAMETER;
goto err_jinfo_free;
}
@@ -9690,7 +9689,7 @@ WERROR _spoolss_GetJob(struct pipes_struct *p,
pdb = get_print_db_byname(svc_name);
if (pdb == NULL) {
DEBUG(3, ("failed to get print db for svc %s\n", svc_name));
- result = WERR_INVALID_PARAM;
+ result = WERR_INVALID_PARAMETER;
goto err_pinfo_free;
}
@@ -9698,7 +9697,7 @@ WERROR _spoolss_GetJob(struct pipes_struct *p,
release_print_db(pdb);
if (sysjob == -1) {
DEBUG(3, ("no sysjob for spoolss jobid %u\n", r->in.job_id));
- result = WERR_INVALID_PARAM;
+ result = WERR_INVALID_PARAMETER;
goto err_pinfo_free;
}
@@ -9818,7 +9817,7 @@ WERROR _spoolss_GetPrinterDataEx(struct pipes_struct *p,
/* check to see if the keyname is valid */
if (!strlen(r->in.key_name)) {
- result = WERR_INVALID_PARAM;
+ result = WERR_INVALID_PARAMETER;
goto done;
}
@@ -9915,7 +9914,7 @@ WERROR _spoolss_SetPrinterDataEx(struct pipes_struct *p,
if (Printer->printer_type == SPLHND_SERVER) {
DEBUG(10,("_spoolss_SetPrinterDataEx: "
"Not implemented for server handles yet\n"));
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
}
if (!get_printer_snum(p, r->in.handle, &snum, NULL)) {
@@ -10148,7 +10147,7 @@ WERROR _spoolss_DeletePrinterKey(struct pipes_struct *p,
/* if keyname == NULL, return error */
if ( !r->in.key_name )
- return WERR_INVALID_PARAM;
+ return WERR_INVALID_PARAMETER;
if (!get_printer_snum(p, r->in.handle, &snum, NULL)) {
return WERR_INVALID_HANDLE;
@@ -10216,13 +10215,13 @@ WERROR _spoolss_EnumPrinterDataEx(struct pipes_struct *p,
/*
* first check for a keyname of NULL or "". Win2k seems to send
* this a lot and we should send back WERR_INVALID_PARAM
* no need to spend time looking up the printer in this case.
* --jerry
*/
if (!strlen(r->in.key_name)) {
- result = WERR_INVALID_PARAM;
+ result = WERR_INVALID_PARAMETER;
goto done;
}
@@ -10314,7 +10313,7 @@ WERROR _spoolss_GetPrintProcessorDirectory(struct pipes_struct *p,
/* that's an [in out] buffer */
if (!r->in.buffer && (r->in.offered != 0)) {
- result = WERR_INVALID_PARAM;
+ result = WERR_INVALID_PARAMETER;
goto err_info_free;
}
@@ -10216,13 +10215,13 @@ WERROR _spoolss_EnumPrinterDataEx(struct pipes_struct *p,
/*
* first check for a keyname of NULL or "". Win2k seems to send
- * this a lot and we should send back WERR_INVALID_PARAM
+ * this a lot and we should send back WERR_INVALID_PARAMETER
* no need to spend time looking up the printer in this case.
* --jerry